The values of the wet-bulb temperature, in Kelvin, in the same shape as p, T, and rh.
Arguments
p
The total air pressuire in Pa. This can be a single number, a vector, a matrix, or an array.
T
The absolute air temperature in Kelvin. This can be a single number, a vector, a matrix, or an array.
rh
The relative humidity of the air, with values in the range of 0 to 1, with respect to saturation over liquid water for air temperatures over 273.16 K and with respect to saturation over ice for air temperatures lower than 273.16 K. This can be a single number, a vector, a matrix, or an array.
psychrometric
A logical indicating whether to calculate the thermodynamic wet-bulb temperature (if FALSE) or the psychometric (a.k.a., ventilated or aspirated) wet-bulb temperature (if TRUE). Default is FALSE.
icebulb
A logical indicating whether to calculate the temperature of an ice-bulb (if TRUE) or wet-bulb (if FALSE). Default is FALSE.
verbose
A logical indicating whether or not to print warning messages. Default is TRUE.