rh_from_wetbulb: Relative humidity from wet-bulb temperature
Description
rh_from_wetbulb calculates the relative humidity from the thermodynamic (or psychrometric) wet-bulb (or ice-bulb) temperature using the Rankine-Kirchhoff approximations.
Relative humidity in the same shape as p, T, and Tw. The relative humidity is reported with respect to liquid water if T is greater than or equal to 273.16 K and with respect to ice if T is less than 273.16 K.
Arguments
p
The total air pressuire in Pa. This can be a single number, a vector, a matrix, or an array.
T
The absolute air temperature in Kelvin. This can be a single number, a vector, a matrix, or an array.
Tw
The thermodynamic (or psychrometric) wet-bulb (or ice-bulb) temperature in Kelving. This can be a single number, a vector, a matrix, or an array.
psychrometric
A logical indicating whether to interpret Tw as the psychrometric (if TRUE) or thermodynamic (if FALSE) version. Default is FALSE.
icebulb
A logical indicating whether to interpret Tw as the ice-bulb (if TRUE) or wet-bulb (if FALSE) version. Default is FALSE.
verbose
A logical indicating whether or not to print warning messages. Default is TRUE.